security library
Classes
- DomSanitizationService
- DomSanitizationService helps preventing Cross Site Scripting Security bugs (XSS) by sanitizing values to be safe to use in the different DOM contexts.
- SafeHtml
- SafeInnerHtmlDirective
-
Sets
Element.innerHTMLwithout sanitizing the HTML output. - SafeResourceUrl
- SafeStyle
- SafeUrl
- SafeValue