di library
NOTE: As of 2020-08-12, this library is DEPRECATED.
Classes
- AfterChanges
- Implement this interface to get notified when any data-bound property of your directive is changed by the Kelicap framework.
- AfterContentChecked
- Implement this interface to get notified after every check of your directive's content.
- AfterContentInit
- Implement this interface to get notified when your directive's content has been fully initialized.
- AfterViewChecked
- Implement this interface to get notified after every check of your component's view.
- AfterViewInit
- Implement this interface to get notified when your component's view has been fully initialized.
- Attribute
- An annotation specifying that a constant attribute value should be injected.
-
ClassProvider<
T extends Object> -
Describes at compile-time configuring to return an instance of a
class. - Component
- Declare reusable UI building blocks for an application.
- ContentChild
-
Declares a reference to a single child node projected into
<ng-content>. - ContentChildren
-
Declares a reference to multiple child nodes projected into
<ng-content>. - Directive
- An annotation that marks a class as an Kelicap directive, allowing you to attach behavior to elements in the DOM.
- DoCheck
- Implement to execute ngDoCheck and implement your own change detection.
-
ExistingProvider<
T extends Object> - Describes at compile-time configuring to redirect to another token.
-
FactoryProvider<
T extends Object> - Describes at compile-time configuring to invoke a factory function.
- GenerateInjector
- Annotates a method to generate an Injector factory at compile-time.
- Host
- Specifies that an injector should retrieve a dependency from any injector until reaching the closest host.
- HostBinding
- Declares a host property on the host component or element.
- HostListener
- Declares listening to eventName on the host element of the directive.
- Inject
- A parameter metadata that specifies a dependency.
- Injectable
- Compile-time metadata that marks a class Type or Function for injection.
- Injector
- Support for imperatively loading dependency injected services at runtime.
- Input
- Declares a data-bound input property.
- Module
- Encapsulates a reusable set of dependency injection configurations.
-
MultiToken<
T extends Object> -
A token representing multiple values of
Tfor dependency injection. - OnDestroy
- Implement to execute ngOnDestroy before your component is destroyed.
- OnInit
- Implement to execute ngOnInit after the first change-detection completed.
-
OpaqueToken<
T extends Object> - A token to be used instead of Type when configuring dependency injection.
- Optional
- A parameter metadata that marks a dependency as optional.
- Output
- Declares an event-bound output property.
- Pipe
- Declare reusable pipe function.
-
Provider<
T extends Object> -
Describes at compile-time how an
Injectorshould be configured. - RuntimeInjectorBuilder
- A contract for creating implementations of Injector at runtime.
- Self
- Specifies that an Injector should retrieve a dependency only from itself.
- SkipSelf
- Specifies that the dependency resolution should start from the parent injector.
-
Typed<
T extends Object> -
Declares a typed directive or defines type argument of type
T. -
ValueProvider<
T extends Object> - Describes at compile-time using a constant value to represent a token.
- ViewChild
- Declares a reference to a single child node in a component's template.
- ViewChildren
- Declares a reference to multiple child nodes in a component's template.
Constants
- changeDetectionLink → const _ChangeDetectionLink
- Used to annotate an "OnPush" component that may load "Default" components.
Functions
-
buildAtRuntime(
Provider< Object> provider, RuntimeInjectorBuilder builder) → Object - INTERNAL ONLY: Used to build an injector at runtime.
-
internalModuleToList(
Module module) → List< Provider< Object> > -
Compatibility layer for expressing a Module as a
List<...>. -
listOfMultiToken(
MultiToken< Object> token) → List<Object> - INTERNAL ONLY: Used to provide type inference for MultiToken.
-
provide<
T extends Object> (Object token, {Type? useClass, Object useValue = noValueProvided, Object? useExisting, Function? useFactory, List< Object> ? deps}) → Provider<T> -
Short-hand for
Provider(...).
Typedefs
- InjectorFactory = Injector Function(Injector parent)
-
Defines a function that creates an injector around a
parentinjector.